<?php
/**
 * The header for our theme
 *
 * @package affiliateblogwriter
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>

<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1.0">
	<?php
	if ( ! function_exists( '_wp_render_title_tag' ) ) {
		/**
		 * Function for render title
		 */
		function theme_slug_render_title() {
			?>

			<?php
				add_theme_support( 'title-tag' );
			?>

			<?php
		}
		add_action( 'wp_head', 'theme_slug_render_title' );
	}
	?>
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
	<div id="site-wrap">
		<div id="site-header">
			<div class="top-menu-wrap">
				<?php
					wp_nav_menu(
						array(
							'theme_location' => 'top-menu',
							'menu_id'        => 'top-menu',
							'container'      => '',
							'fallback_cb'    => false,
						)
					);
					?>
				<?php if ( has_nav_menu( 'top-menu' ) && ( get_theme_mod( 'search_form' ) !== 'no' ) ) { ?>
					<div class="top-search">
						<form id="top-searchform" method="get" action="<?php echo esc_url( home_url() ); ?>">
							<input type="search" name="s" autocomplete="off" placeholder="">
						</form>
					</div>
				<?php } ?>
			</div>
			<h1>
				<a href="<?php echo esc_url( get_home_url() ); ?>">
					<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>
				</a>
			</h1>
			<?php
			if ( esc_attr( get_bloginfo( 'description' ) ) !== '' ) {
				echo '<h2 class="tagline">' . esc_attr( get_bloginfo( 'description' ) ) . '</h2>';
			}
			?>
			<button id="menu-toggle"><svg fill="none" height="24" stroke="#000" stroke-linecap="round"
				stroke-linejoin="round" stroke-width="2" viewBox="0 0 24 24" width="24"
				xmlns="http://www.w3.org/2000/svg">
				<line x1="3" x2="21" y1="12" y2="12" />
				<line x1="3" x2="21" y1="6" y2="6" />
				<line x1="3" x2="21" y1="18" y2="18" /></svg>
			</button>
			<?php if ( is_active_sidebar( 'central-cta-sidebar' ) ) { ?>
				<div class="central-cta-mobile central-cta-sidebar">
					<?php dynamic_sidebar( 'central-cta-sidebar' ); ?>
				</div>
			<?php } ?>
			<div class="main-menu-wrap <?php esc_attr( get_theme_mod( 'fixed_menu' ) ); ?>">
				<?php
				wp_nav_menu(
					array(
						'theme_location' => 'main-menu',
						'menu_id'        => 'main-menu',
						'container'      => '',
						'fallback_cb'    => false,
					)
				);
				?>
				<div class="mobile-menu-search-form">
					<?php get_search_form(); ?>
				</div>
				<div class="mobile-menu-branding">
					<h2>
						<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>
					</h2>
					<?php
					if ( esc_attr( get_bloginfo( 'description' ) ) !== '' ) {
						echo '<h3>' . esc_attr( get_bloginfo( 'description' ) ) . '</h3>';
					}
					?>
				</div>
				<div id="main-menu-placeholder"></div>
			</div>
			<div class="small-mobile-menu-wrap <?php echo esc_attr( get_theme_mod( 'fixed_menu' ) ); ?>">
				<?php
					wp_nav_menu(
						array(
							'theme_location' => 'small-mobile-menu',
							'menu_id'        => 'small-mobile-menu',
							'container'      => '',
							'fallback_cb'    => false,
							'depth'          => 1,
						)
					);
					?>
			</div>
</div>
